[TOC]


# MpdNuclei wagon
MPDRoot wagon for the (light) nuclei analysis.

- [Dependencies](#dependencies)
  - [Branches](#branches)
  - [Wagons](#wagons)
- [Usage](#usage)
- [Configuration](#configuration)
  - [Global settings](#global-settings)
  - [Event settings](#event-settings)
  - [Track settings](#track-settings)
  - [PID settings](#pid-settings)
  - [MpdPid settings](#mpdpid-settings)
  - [evPID settings](#evpid-settings)
  - [Particles settings](#particles-settings)
  - [Example](#example)
- [Documentation](#documentation)

## Dependencies {#dependencies}
### Branches {#branches}
- MCTrack
- TpcKalmanTrack
- ZdcDigi
- Vertex
- MPDEvent
- TOFMatching
- MpdTofMatchingData (optional)  

### Wagons {#wagons}
- evCentrality
- evPID (optional)

## Usage {#usage}
Add these lines to your "train" macro (e.g. `RunAnalyses.C`):
```c
MpdNuclei taskNuclei("taskNuclei", "taskNuclei", "mpdpid_20prc.json");
man.AddTask(&taskNuclei);
```

## Configuration {#configuration}
The JSON file format is used for the MpdNuclei wagon configuration.

### Global settings {#global-settings}
| Key | Default value | Description |
| ------------- |:-------------:| ------------- |
| Verbose | 1 | Print extra output |
| N_MPD_PID_Particles |8| Number of particles predefined for the PID in the `core/mpdBase/MpdTrack.h`|
| make_MC |0| Create and fill histograms for the particles identified by the MC information |
|make_Efficiency | 1 | Create and fill efficiency histograms |
|PID_mode|0|Switch for PID mode: 0 = "evPID"; 2 = "MpdPid"; any other value = turn off|
|DCA_mode|0|Switch for DCA mode: 0 = "classic"; 1 = "NSigma"|
|TOF_mode|0|Switch for ToF matching mode: 0 = "classic" -- check for the ToF flags 2 and 6; 1 = "NSigma" -- check for GetTofDphiSigma() and GetTofDzSigma(); 2 = use MpdTofMatchingData|
|use_pt_corrections | 0 | Switch for the creation of the pT correction 2D profiles |
|pt_corrections_file | N/A |  Name of the input file with the pT correction 2D profiles |
    
### Event settings {#event-settings}
There are no default values here.

| Key | Description |
| ------------- | ------------- |
| PrimaryVertexZ  | Cut for the z-coordinate of the the primary vertex |
| Centrality | A set of the centrality bins for to analyse (`[[min1, max1], [min2, max2], ...]`)|

### Track settings {#track-settings}
There are no default values here.

| Key | Description |
| ------------- | ------------- |
| NHits | Cut for the minimum number of hits |
| NSigmaDCAx | N-Sigma cut for the DCAx |
| NSigmaDCAy | N-Sigma cut for the DCAy |
| NSigmaDCAz | N-Sigma cut for the DCAz |
| LowPtCut | Cut for the minimum transverse momentum |
| HighPtCut | Cut for the maximal transverse momentum |

### PID settings {#pid-settings}
There are no default values here.

| Key | Description |
| ------------- | ------------- |
| TPCSigma | N-Sigma cut for the PID by the TPC dE/dx infomation |
| TOFSigma | N-Sigma cut for the PID by the ToF mass-squared information |
| TOFDphiSigma | N-Sigma cut for the ToF delta-phi (ToF-matching) |
| TOFDzSigma | N-Sigma cut for the ToF delta-z (ToF-matching) |

### MpdPid settings {#mpdpid-settings}
There are no default values here.
Plsease, see `core/mpdPid` for more explanation.

| Key | Description |
| ------------- | ------------- |
|s__mid_Energy|Collision energy|
|s__mid_Coef|MpdPid dE/dx coefficient|
|s__mid_Generator|MpdPid generator string|
|s__mid_Tracking|MpdPid tracking string|
|s__mid_IniString|MpdPid initialization sting|
|s__mid_dEdx|Switch for the use of the "dE/dx only" case in addition to the combined PID|

### evPID settings {#evpid-settings}
There are no default values here.

| Key | Description |
| ------------- | ------------- |
|s__eid_vetoTPC|N-sigma veto for the TPC pid|
|s__eid_vetoToF|N-sigma veto for the ToF pid|


### Particles settings {#particles-settings}
A separate block must be filled for the each particle. There is no default values.

| Key | Description |
| ------------- | ------------- |
| PDG | Monte Carlo particle code, [see the scheme](https://pdg.lbl.gov/2022/reviews/rpp2022-rev-monte-carlo-numbering.pdf) |
| Mass | Particle mass |
| Charge | The absolute value of the particle charge|
| Enum | Particle position in the `core/mpdBase/MpdTrack.h`|
|pt_bins| Number of pT bins, left limit, right limit |
|y_bins| Number of rapidity bins, left limit, right limit |


### Example {#example}
```json
{
    "Verbose": "1",
    "N_MPD_PID_Particles": "8",
    "make_MC": "1",
    "make_Efficiency": "1",
    "PID_mode": "2",
    "DCA_mode": "0",
    "TOF_mode": "0",
    "use_pt_corrections": "0",
    "pt_corrections_file": "pt_corrections.root",
    "Events": {
        "PrimaryVertexZ": "100",
        "Centrality": [[0, 20], [20, 40], [40, 80]]
    },
    "Tracks": {
        "NHits": "20",
        "NSigmaDCAx": "3",
        "NSigmaDCAy": "3",
        "NSigmaDCAz": "3",
        "LowPtCut": "0.05",
        "HighPtCut": "4.0"
    },
    "PID": {
        "TPCSigma": "2",
        "TOFSigma": "2",
        "TOFDphiSigma": "3",
        "TOFDzSigma": "3"
    },
    "MpdPid": {
        "Energy": "9.2",
        "Coef": "1.0",
        "Generator": "PHQMD",
        "Tracking": "CFHM",
        "IniString": "pikaprdetrhe3he4",
        "Add_dedx_only": "1"
    },
    "evPID": {
        "VetoTPC": "3",
        "VetoToF": "3"
    },
    "Particles": {
        "pim": {
            "PDG": "-211",
            "Mass": "0.1395",
            "Charge": "1",
            "Enum": "1",
            "pt_bins": [60, 0.0, 6.0],
            "rapidity_bins": [60, -3.0, 3.0]
        },
        "pip": {
            "PDG": "211",
            "Mass": "0.1395",
            "Charge": "1",
            "Enum": "1",
            "pt_bins": [60, 0.0, 6.0],
            "rapidity_bins": [60, -3.0, 3.0]
        },
        "km": {
            "PDG": "-321",
            "Mass": "0.493677",
            "Charge": "1",
            "Enum": "2",
            "pt_bins": [60, 0.0, 6.0],
            "rapidity_bins": [60, -3.0, 3.0]
        },
        "kp": {
            "PDG": "321",
            "Mass": "0.493677",
            "Charge": "1",
            "Enum": "2",
            "pt_bins": [60, 0.0, 6.0],
            "rapidity_bins": [60, -3.0, 3.0]
        },
        "p": {
            "PDG": "2212",
            "Mass": "0.938",
            "Charge": "1",
            "Enum": "3",
            "pt_bins": [60, 0.0, 6.0],
            "rapidity_bins": [60, -3.0, 3.0]
        },
        "ap": {
            "PDG": "-2212",
            "Mass": "0.938",
            "Charge": "1",
            "Enum": "3",
            "pt_bins": [60, 0.0, 6.0],
            "rapidity_bins": [60, -3.0, 3.0]
        },
        "d": {
            "PDG": "1000010020",
            "Mass": "1.876",
            "Charge": "1",
            "Enum": "4",
            "pt_bins": [30, 0.0, 6.0],
            "rapidity_bins": [60, -3.0, 3.0]
        },
        "t": {
            "PDG": "1000010030",
            "Mass": "2.814",
            "Charge": "1",
            "Enum": "5",
            "pt_bins": [20, 0.0, 6.0],
            "rapidity_bins": [60, -3.0, 3.0]
        },
        "He3": {
            "PDG": "1000020030",
            "Mass": "2.814",
            "Charge": "2",
            "Enum": "6",
            "pt_bins": [20, 0.0, 6.0],
            "rapidity_bins": [60, -3.0, 3.0]
        },
        "He4": {
            "PDG": "1000020040",
            "Mass": "3.752",
            "Charge": "2",
            "Enum": "7",
            "pt_bins": [15, 0.0, 6.0],
            "rapidity_bins": [60, -3.0, 3.0]
        }
    }
}
```


## Documentation {#documentation}
To generate the MpdNuclei class documentation one can use the Doxygen genetator:
``` doxygen doxygen_config ```
The generated documentation will be placed in the newly created folder: ```html/index.html```.
